@@ -6,7 +6,7 @@ from typing import Any
 
 import requests
 
-from .dependencies import check_upload_status_code, handle_download_response
+from .dependencies import check_upload_status_code, handle_retrieve_state_response
 from ..core.azure_client_authorization import ClientAuthorization
 
 logger = logging.getLogger(__name__)
@@ -128,4 +128,4 @@ class Ingress:
             headers={'Authorization': self.client_auth.get_access_token()}
         )
 
-        return handle_download_response(response)
+        return handle_retrieve_state_response(response)
