@@ -31,19 +31,14 @@ class FileBatchController:
    """
 
     STATE_FILE = 'transformation_state.json'
-    DATE_FORMAT = '%Y-%m-%dT%H:%M:%S'
+    DATE_FORMAT = '%Y-%m-%dT%H:%M:%SZ'
 
-    # pylint: disable=too-many-arguments
     def __init__(self,
-                 client_auth: ClientAuthorization,
-                 account_url: str,
-                 filesystem_name: str,
-                 guid: str,
+                 dataset: Dataset,
                  ingest_time: datetime = None,
                  max_files: int = 10):
 
-        if None in [client_auth, account_url, filesystem_name, guid]:
-            raise TypeError
+        client_auth, account_url, filesystem_name, guid = dataset.get_configuration()
 
         self.client_auth = client_auth
         self.account_url = account_url
@@ -77,12 +72,20 @@ class FileBatchController:
 
         return paths
 
+    def __get_datetime_from_string(self, date_time: str):
+        for datetime_format in [self.DATE_FORMAT, '%Y-%m-%dT%H:%M:%S']:
+            try:
+                return datetime.strptime(date_time, datetime_format)
+            except ValueError:
+                pass
+        raise ValueError('No valid date format found')
+
     def __get_paths_since_last_run(self, filesystem_client: FileSystemClient, max_files: int) -> List[PathProperties]:
         state = self.__retrieve_transformation_state(filesystem_client)
 
-        last_successful_run = datetime.strptime(state['last_successful_run'], self.DATE_FORMAT)
+        last_successful_run = self.__get_datetime_from_string(state['last_successful_run'])
         if 'last_backfill_start' in state:
-            self.last_backfill_start = datetime.strptime(state['last_backfill_start'], self.DATE_FORMAT)
+            self.last_backfill_start = self.__get_datetime_from_string(state['last_backfill_start'])
 
         now = datetime.utcnow()
         time_range = pd.date_range(last_successful_run, now, freq='H')
@@ -112,7 +115,7 @@ class FileBatchController:
                 state = file_client.download_file().readall()
                 return json.loads(state)
             except ResourceNotFoundError:
-                return {'last_successful_run': '2018-01-01T00:00:00'}
+                return {'last_successful_run': '2018-01-01T00:00:00Z'}
 
     def __save_transformation_state(self, filesystem_client: FileSystemClient, state: Dict):
         with filesystem_client.get_file_client(f'{self.guid}/{self.STATE_FILE}') as file_client:
@@ -128,20 +131,13 @@ class FileBatchController:
 
             for path in paths:
                 processed_file_metadata = file_system_client.get_file_client(path.name).get_file_properties().metadata
-                # Only append files which does not have the status=processed or processing tag
-                # NOTE: some "processing" files might not have run if transformation fails. Remove the tag, then rerun
 
+                # We check if data should be processed again
                 if 'processed' not in processed_file_metadata:
                     unprocessed_files.append(path)
-                elif self.last_backfill_start > datetime.strptime(processed_file_metadata['processed'],
-                                                                  self.DATE_FORMAT):
+                elif self.last_backfill_start > self.__get_datetime_from_string(processed_file_metadata['processed']):
                     unprocessed_files.append(path)
 
-                # if 'status' not in processed_file_metadata:
-                #     unprocessed_files.append(path)
-                # elif processed_file_metadata['status'] not in ['processed', 'processing']:
-                #     unprocessed_files.append(path)
-
             return unprocessed_files
         except ResourceNotFoundError:
             return []
@@ -186,9 +182,9 @@ class FileBatchController:
                 date_elements = self.file_paths[-1].name.split('/')[1:-1]
                 date_str = ''.join([x.split('=')[1] for x in date_elements])
 
-                latest_folder_date = datetime.strptime(date_str, '%Y%m%d%H').isoformat()
+                latest_folder_date = datetime.strptime(date_str, '%Y%m%d%H').strftime(self.DATE_FORMAT)
                 state['last_successful_run'] = latest_folder_date
-                state['last_backfill_start'] = self.last_backfill_start
+                state['last_backfill_start'] = self.last_backfill_start.strftime(self.DATE_FORMAT)
                 self.__save_transformation_state(filesystem_client, state)
 
 
@@ -199,7 +195,6 @@ class DatalakeFileSource(iobase.BoundedSource):  # noqa
     Class takes a list of paths to process in the batch.
     """
 
-    # pylint: disable=too-many-arguments
     def __init__(self,
                  dataset: Dataset,
                  file_paths: List[str]):
